Re-exports
pub use graphics::*;
Modules
Structs
- App
- Represents the context of the application
- AppBuilder
- The builder is charge of create and configure the application
- AppTimer
- Helper to measure and expose application’s time events
- Event
Iterator - Event iterator queue
- Plugins
- A container of plugins that allow get them to use it
- Window
Config - Builder configuration for the window options
Enums
- AppFlow
- Control the flow of the application
- Cursor
Icon - Represent mouse cursor icon They are same as egui::CursorIcon because this is mostly to give support to egui
- Event
- Application events usually received from the user
- Frame
State - Indicate to the backend if the frame was skipped or if it ended
Traits
- AppLoader
- AppRunner
- AppState
- Represents the state of the application, always accessible across the event’s cycle
- Backend
- Represents the backend implementation
- Backend
Runner - A closure that initializes and runs the app
- Backend
System - Backend initialization run
- Build
Config - Configurations used at build time
- Plugin
- A plugin allow the user to extend or alter the application
- Setup
Handler - Window
Backend - Represents a window
Type Aliases
- Initialize
Fn - Closure returned from the backend’s initialize method
- Load
File Fn - Closure used to load files