pub struct TextureUpdater<'a> { /* private fields */ }Implementations
Sourceimpl<'a> TextureUpdater<'a>
impl<'a> TextureUpdater<'a>
pub fn new( device: &'a mut Device, texture: &'a mut Texture, ) -> TextureUpdater<'a>
Sourcepub fn with_x_offset(self, offset: u32) -> TextureUpdater<'a>
pub fn with_x_offset(self, offset: u32) -> TextureUpdater<'a>
Update pixels from the axis x offset
Sourcepub fn with_y_offset(self, offset: u32) -> TextureUpdater<'a>
pub fn with_y_offset(self, offset: u32) -> TextureUpdater<'a>
Update pixels from the axis y offset
Sourcepub fn with_width(self, width: u32) -> TextureUpdater<'a>
pub fn with_width(self, width: u32) -> TextureUpdater<'a>
Update pixels until this width from the x offset value
Sourcepub fn with_height(self, height: u32) -> TextureUpdater<'a>
pub fn with_height(self, height: u32) -> TextureUpdater<'a>
Update pixels until this height from the y offset value
pub fn with_source<S>(self, source: S) -> TextureUpdater<'a>where
S: TextureSource + 'static,
pub fn with_data(self, bytes: &'a [u8]) -> TextureUpdater<'a>
pub fn update(self) -> Result<(), String>