WindowConfig

Struct WindowConfig 

pub struct WindowConfig {
Show 23 fields pub title: String, pub width: u32, pub height: u32, pub fullscreen: bool, pub min_size: Option<(u32, u32)>, pub max_size: Option<(u32, u32)>, pub position: Option<(i32, i32)>, pub maximized: bool, pub resizable: bool, pub vsync: bool, pub multisampling: u8, pub high_dpi: bool, pub lazy_loop: bool, pub transparent: bool, pub always_on_top: bool, pub decorations: bool, pub visible: bool, pub mouse_passthrough: bool, pub app_id: String, pub window_icon_path: Option<PathBuf>, pub window_icon_data: Option<&'static [u8]>, pub taskbar_icon_path: Option<PathBuf>, pub taskbar_icon_data: Option<&'static [u8]>,
}
Builder configuration for the window options

Fields

title: String

Window’s title Web: no-op

width: u32

Window’s width

height: u32

Window’s height

fullscreen: bool

Start window in fullscreen mode Web: no-op

min_size: Option<(u32, u32)>

Minimum resizable window’s size

max_size: Option<(u32, u32)>

Maximum resizable window’s size

position: Option<(i32, i32)>

Window’s x/y start position

maximized: bool

Start the window maximized Web: The canvas will fill the size of the parent of the HtmlCanvasElement

resizable: bool

Allow to resize the window Web: The canvas will resize along with the parent of the HtmlCanvasElement

vsync: bool

Enable V-Sync Web: no-op

multisampling: u8

Sets multisampling Setting to 0 disables multisampling

high_dpi: bool

Enable High DPI viewport and drawing if the device pixel ratio is higher than 1 This is false by default, enable it could consume more resources and require a custom way of drawing things. The advice is using it if you know what you’re doing

lazy_loop: bool

Inner loop will run only after an input event

transparent: bool

Background as transparent

always_on_top: bool

Window will be drawn above others

decorations: bool

Enable decorations Web: Does nothing

visible: bool

Hide the windows

mouse_passthrough: boolapp_id: String

App ID On Web use or create the canvas with this id.

window_icon_path: Option<PathBuf>

Optinal Window icon filepath

window_icon_data: Option<&'static [u8]>

Optinal Window icon filedata

taskbar_icon_path: Option<PathBuf>

Optinal Task bar icon filepath

taskbar_icon_data: Option<&'static [u8]>

Optinal Task bar icon filedata

Implementations

Source

impl WindowConfig

pub fn new() -> Self

Create a new instance using default values

pub fn set_title(self, title: &str) -> Self

Sets the window’s title

pub fn set_lazy_loop(self, lazy: bool) -> Self

Inner loop will run only after an input event

pub fn set_size(self, width: u32, height: u32) -> Self

Sets the window’s width and height

pub fn set_fullscreen(self, fullscreen: bool) -> Self

Enable fullscreen mode

pub fn set_min_size(self, width: u32, height: u32) -> Self

Sets the window’s minimum size

pub fn set_max_size(self, width: u32, height: u32) -> Self

Sets the window’s maximum size

pub fn set_position(self, x: i32, y: i32) -> Self

Sets the window’s x and y

pub fn set_maximized(self, maximized: bool) -> Self

Starts the window maximized

pub fn set_resizable(self, resizable: bool) -> Self

Allow the window to be resizable

pub fn set_vsync(self, vsync: bool) -> Self

Enable vsync

pub fn set_multisampling(self, samples: u8) -> Self

Sets multisampling Setting to 0 disables multisampling

pub fn set_high_dpi(self, enabled: bool) -> Self

Enable High DPI

pub fn set_transparent(self, transparent: bool) -> Self

Set the background as transparent

pub fn set_always_on_top(self, always_on_top: bool) -> Self

Set the background as transparent

pub fn set_decorations(self, decorations: bool) -> Self

Enable or disable decorations

pub fn set_visible(self, visible: bool) -> Self

Hide or show the window

pub fn set_mouse_passthrough(self, mouse_passthrough: bool) -> Self

Mouse events pass through window

pub fn set_app_id(self, app_id: &str) -> Self

Set the App ID On web it will use or create the canvas with this id.

pub fn set_window_icon(self, window_icon_path: Option<PathBuf>) -> Self

Window icon path

pub fn set_window_icon_data( self, window_icon_data: Option<&'static [u8]>, ) -> Self

Window icon data

pub fn set_taskbar_icon(self, taskbar_icon_path: Option<PathBuf>) -> Self

Task bar icon path

pub fn set_taskbar_icon_data( self, taskbar_icon_data: Option<&'static [u8]>, ) -> Self

Task bar icon data